;+
; NAME:
;	ARRAY
; PURPOSE:
;	Force data to be an array.
; CATEGORY:
;	Programming.
; CALLING sequence:
;	Y = ARRAY(X)
; INPUTS:
;	X = input data.
; OUTPUTS:
;	Y = X forced to be an array.
; PROCEDURE:
;	IFG: Won't N always be 1 if DATATYPE(X) NE 'UND'?
;	IFG: Instead of CASEs, couldn't REPLICATE be used for all datatypes?
; MODIFICATION HISTORY:
;	RES  28 Jan, 1986.
;	IFG   7 Feb, 1991:  Converted to IDL2. Added Structure.
;	IFG, 22 Dec 1992: Added ON_ERROR.
;	   Noted differences wrt ARRAY in UTIL_IDL.TLB:
;	      Uses call to IDL2 STRARR rather than IDL1 STRARR.
;	      Has 'STU' case for structured variables.
;-

	FUNCTION ARRAY, X

	ON_ERROR, 2
	S = SIZE(X)
	IF S(0) GT 0 THEN RETURN, X	; already an array.
	N = S(S(0)+2)			; number of elements.
	TYP = DATATYPE(X)
	IF TYP EQ 'UND' THEN RETURN, INTARR(1)

	CASE TYP OF
  'STR': BEGIN
	   Y = STRARR(1)
	   Y(0) = X
	 END
  'BYT': Y = BYTARR(N) + X
  'INT': Y = INTARR(N) + X
  'LON': Y = LONARR(N) + X
  'FLO': Y = FLTARR(N) + X
  'DOU': Y = DBLARR(N) + X
  'COM': Y = COMPLEXARR(N) + X
  'STU': Y = REPLICATE(X,1)
   ELSE: RETURN, X
	ENDCASE

	RETURN, Y
	END
