pro CLOSE_PS,$
      print=k_prnt,delete=k_del,queue=k_que,color_printer=k_cp
;
;+
; NAME:
;    CLOSE_PS
; PURPOSE:
;    Closes a PostScript file opened by OPEN_PS2. The user also has the
;    option sending the file to a printer (w/wo delete) or deleting the
;    file after closing (if unwanted).
; CATEGORY:
;    Utility
; CALLING SEQUENCE:
;    CLOSE_PS   [,/PRINT] [,/DELETE] 
;               [,QUEUE=queue_number] [,/COLOR_PRINTER]
; INPUTS:
;    No input pararmeters
; OPTIONAL INPUT PARAMETERS:
;    No input pararmeters
; KEYWORD PARAMETERS:
;    PRINT              - Submits the file to a PostScript print queue
;    DELETE             - if printing, deletes file after printing
;                         if not printing, deletes file after closing (user 
;                                confirmation required)
;    QUEUE=queue_number - Selects the QMS queue number
;                            ex; queue_number=3 - prints on QMS3
;    COLOR_PRINTER      - Selects the color printer queue (QMSC1)
; OUTPUTS:
;    No output pararmeters
; OPTIONAL OUTPUT PARAMETERS:
;    No output pararmeters
; COMMON BLOCKS:
;    common PS_FILE_INFO,ps_file,Old_device,Old_setup
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; PROCEDURE:
;     The PostScript file is opened using OPEN_PS2 and closed using CLOSE_PS2
;
; MODIFICATION HISTORY:
;     10-April-1992 - Created By J D Trickey baised on previous versions 
;     18-may-1994 -J.D.Trickey - added free_lun call
;
;-
;
;
common PS_FILE_INFO,ps_file,Old_device,Old_setup
;
if n_elements(ps_file) eq 0 then ps_file=''
;
if strtrim(ps_file,2) eq '' then begin
   print,'--- Postscript file not open ---'
   return
endif
;
old_unit=!d.unit
device,/close
if old_unit ne 0 then free_lun,old_unit
set_plot,old_device.name
!p=old_setup
;
;      +-------------------------------------------------------------------+
;      |Get the name of the file again, this time with version number      |
;      +-------------------------------------------------------------------+
istat=findfile(ps_file)
ps_file=istat(0)
print,' Postscript file ',ps_file,' closed.'
;
if keyword_set(k_prnt) then begin
   if keyword_set(k_que) then begin
      que_name='qms'+strtrim(string(k_que),2)
   endif else begin
      if keyword_set(k_cp) then que_name='qmsc1' else que_name='qms1'
   endelse
   command='print/que='+que_name+' '+ps_file
   if keyword_set(k_del) then command=command+'/delete'
   spawn,command,/nowait
endif else if keyword_set(k_del) then begin
   command='delete/confirm '+ps_file+';'
   spawn,command
endif
;
;
ps_file=' '
;
return
end
      
