;+
; NAME:     CIVIL_TIME
; PURPOSE:  Returns the calendar date given Canopus Time. Code is all IDL.
;           CANOPUS time is defined as seconds since 00:00:00 January 1, 1986.
; CALLING SEQUENCE:
;           CIVIL_TIME,year,month,date,day,hour,minute,second,can_time
; INPUTS:   CAN_TIME (Canopus Time)
; OUTPUTS:  YEAR, MONTH, DATE, DAY, HOUR, MINUTE and SECOND.
;           DATE is day-of-month, DAY is day-of-year.
; PROCEDURE:
;           Calls user library routines CALDAT and JULDAT for date conversions.
;           Does not call a FORTRAN image.
; MODIFICATION HISTORY:
;           14 Sep 1993, GRANT, UWO: Written by modifying CIVIL_TIME.PRO
;              (Written: F.Creutzberg,  5-APR-1989, Last Modified: 20-NOV-1992
;              03:08:16.68).
;-

pro civil_time, year,month,date,day,hour,minute,second,can_time

on_error, 2
if n_params(0) lt 8 then begin
   print,'You MUST provide 8 parameters: Yr, Mo, Da, Dn, Hr, Mn, Sc, C_T'
   return
endif
;stop
if (can_time eq -2147483647) then message, 'Bad input CAN_TIME'

can_tim=long(can_time)
secs_in_day = 86400L
jd0 = julday(1,1,1986)

days = can_tim / secs_in_day
jd = jd0 + days
caldat, jd, month, date, year
day = jd - julday(1L,1L,year) + 1L

can_tim = can_tim mod secs_in_day	; Seconds of day
hour = can_tim / 3600L

can_tim = can_tim mod 3600L		; Seconds of hour
minute = can_tim / 60L
second = can_tim mod 60L

return
end
