PRO LD_CTABLE, TABLE_NUMBER, SILENT = SILENT
;+
; NAME:        LD_CTABLE
; PURPOSE:     Load predefined color tables from a user defined file 
;              containing colour tables. The file accessed in this
;              version is MPA$EXE:IDL.CTABLE.
; CATEGORY:    Image display.
; CALLING SEQUENCE:
;     LD_CTABLE [, TABLE_NUMBER]
; INPUTS:
;     Table_number = number of table to load, from 0 to 15.
;        If omitted, a menu of the available tables is printed
;        and the user is prompted for the table number.
; KEYWORD PARAMETERS:
;     Silent = If present and non-zero, supress the Color Table
;        message.
; OUTPUTS:
;     No explicit outputs.
; COMMON BLOCKS:
;     Maintains the common block colors.
; SIDE EFFECTS:
;     The color tables of the currently selected device are modified.
; RESTRICTIONS:
;     Works from the file: MPA$EXE:IDL.CTABLE.
; PROCEDURE:
;     The file IDL.CTABLE is read.  A maximum of 16 entries may 
;     be defined.  The titles of each table are contained in the first 
;     16 * 32 characters/name bytes.  If the currently selected device
;     doesn't have 256 colors, the color data is interpolated  from
;     256 colors to the number of colors available.
;
;     The colors loaded into the display are saved in the common
;     block COLORS, as both the current and original color vectors.
;
;     You can use the procedure CH_CTABLE to save your own color tables
;     in the file IDL.CTABLE. You can use the procedure MD_CTABLE to 
;     modify the color tables in that file and XT_CTABLE to extract the
;     color tables from that file.
;
;     INTERPOLATION:  If the current device has less than 256 colors,
;     the color table data are interpolated to cover the number of
;     colors in the device.
;  MODIFICATION HISTORY:
;     Changed for MPA tables from original IDL colour tables by 
;        F.Creutzberg    6-NOV-1991
;     Colour Table moved to UTIL$SOFT
;        F.Creutzberg   30-JUL-1992
;     Replaced obsolete logical UTIL$SOFT with UTL$IDL$DAN.
;     Filename was undefined.
;        D. Tanguay	14-DEC-1993
;-
   common colors, r_orig, g_orig, b_orig, r_curr, g_curr, b_curr

   nc = !d.table_size                     ; # of colors in this device.

   if nc eq 0 then message, 'Device has static color tables.  Can''t load.'

   on_ioerror, bad
   on_error, 2                            ;Return to caller if error
   get_lun, lun

   filename = 'UTL$IDL$DAN:IDL.CTABLE'
   openr, lun, filename, /block
   aa =  assoc(lun, bytarr(32))              ;Get name
   if n_params() lt 1 then begin             ;Summarize table?
   for i=0,15 do print,i,' - ',string(aa(i))
      read,'Enter table number: ',table_number
      endif

   if (table_number ge 16) or (table_number lt 0) then begin
      message, 'Table number must be from 0 to 15.'
   end


   if keyword_set(silent) eq 0 then $
	   message,'Loading table ' + string(aa(table_number)),/INFO
   aa=assoc(lun, bytarr(256),512)	;Read 256 long ints
   r_orig = aa(table_number*4)
   g_orig = aa(table_number*4+1)
   b_orig = aa(table_number*4+2)

   if nc ne 256 then begin	;Interpolate
      p = (lindgen(nc) * 256) / nc
      r_orig = r_orig(p)
      g_orig = g_orig(p)
      b_orig = b_orig(p)
   endif

   r_curr = r_orig
   g_curr = g_orig
   b_curr = b_orig
   tvlct,r_orig, g_orig, b_orig

;  Fix up the color table. Highest entry must be white!!
   tvlct,/get,r,g,b
   n = n_elements(r) - 1
   r(n) = 255 & g(n) = 255 & b(n) = 255
   tvlct,r,g,b
   goto, close_file

BAD:
   message,'Error reading file: ' + filename + ', ' + !err_string

CLOSE_FILE:
  free_lun,lun
  return
END
