pro oplot_drop,x_array,y_array,drop=drp_fill,ydrop=yd,$
    symsize=smsz,psym=psm,linestyle=lnstl,noclip=noclip,color=color,$
    thickness=thck
;
;+
; NAME: Oplot_drop
; PURPOSE: To "OPLOT" only under a given fill value [default = 99999.0]
; CATEGORY: plotting
; CALLING SEQUENCE:
;   OPLOT_DROP,Y
;   OPLOT_DROP,X,Y
;   OPLOT_DROP,X,Y [,DROP=drp_fill] [,/YDROP] [,PSYM=symbol] [,SYMSIZE=value]
;                  [,LINESTYLE= style] [,COLOR= color] [,THICKNESS=thick]
;                  [,/NOCLIP]
; INPUTS:
;   x,y    - real array - data coordinates
; OPTIONAL INPUT PARAMETERS: None
; KEYWORD PARAMETERS: 
;   Drop   - value to be used as "fill" value, any data over this value
;            will not be plotted.
;   Ydrop  - find drop gaps using Y data only
;   PSYM   - determines symbol type to be used for these points
;   SYMSIZE - controls the size of the symbols plotted, default = 1.0
;   LINESTYLE - determines the line style to be used to plot data
;   COLOR - determines the line colour to be used to plot data
;   THICKNESS - determines the line thickness to be used to plot data
;   NOCLIP - determines if data point will be clipped (excluded and not
;             plotted) if they are outside the plot box. Default is clipping.
; OUTPUTS: None
; OPTIONAL OUTPUT PARAMETERS: None
; COMMON BLOCKS: None
; SIDE EFFECTS: None
; RESTRICTIONS: Not designed for the 3-d plotting available in IDL 2
; PROCEDURE:
;   The plot axis must be set (ex. uning a PLOT command) before using this
;   procedure
; MODIFICATION HISTORY:
;   Created - Dec 1990 - J.D.Trickey
;   Added DROP= keyword - Dec 1990 - J.D. Trickey 
;   Added keywords PSYM, SYMSIZE and LINESTYLE - Jan 1990 - J.D. Trickey 
;   Added keyword THICKNESS - Oct 1992 - J.D. Trickey 
;-
if n_params(0) eq 1 then begin			;Only Y_ARRAY passed.
	y = x_array
	x = findgen(n_elements(y))
endif else begin
   x=x_array
   y=y_array
endelse
if keyword_set(noclip) then noclip_val=1 else noclip_val=0
If n_elements(drp_fill) ne 0 then fill=drp_fill else fill=99999.0
If keyword_set(smsz) then size=smsz else size=1.0
If n_elements(psm) ne 0 then begin
    psym_old=!p.psym
    !p.psym = psm
endif
If n_elements(lnstl) ne 0 then begin
    linestyle_old=!p.linestyle
    !p.linestyle = lnstl
endif
If n_elements(color) ne 0 then begin
    color_old=!p.color
    !p.color = color
endif
If n_elements(thck) ne 0 then begin
    thick_old=!p.thick
    !p.thick = thck
endif
;
If keyword_set(yd) then begin
   igood=where(y lt fill)
   if igood(0) eq -1 then return 
   ibad=where(y ge fill) 
endif else begin
   igood=where(x lt fill)
   if igood(0) eq -1 then begin
        igood=where(y lt fill)
        if igood(0) eq -1 then return else begin
             ibad=where(y ge fill)        ; x represents time (all point over fill)
        endelse
   endif else begin
        igood=where(y lt fill)
        if igood(0) eq -1 then return else begin
             ibad=where((x ge fill) or (y ge fill))
        endelse
   endelse
endelse
;
skips=n_elements(ibad)
numx=n_elements(x)
count=0
start=0
;
if ibad(0) eq -1 then oplot,x,y,symsize=size,noclip=noclip_val else begin
    while count le skips do Begin
       if start le numx-1 then begin
          pf=0
          if count eq skips then begin
             x1=x(start:numx-1)
             y1=y(start:numx-1)
             pf=1
          endif else begin 
             if ibad(count) gt 0 then begin 
                x1=x(start:ibad(count)-1)
                y1=y(start:ibad(count)-1)
                pf=1
             endif
          endelse
          if pf eq 1 then oplot,x1,y1,symsize=size,noclip=noclip_val
       endif
;
       loop=0
       count=count+1
       while loop eq 0 do Begin
            if (count lt skips) then begin
               if (ibad(count-1) eq ibad(count)-1) then begin 
                  count=count+1
               endif else loop=1
            endif else loop=1 
       endwhile
       if (count le skips) then start=ibad(count-1)+1
    endwhile
endelse
;
If n_elements(psm) ne 0 then begin
    !p.psym = psym_old
endif
If n_elements(lnstl) ne 0 then begin
    !p.linestyle = linestyle_old
endif
If n_elements(color) ne 0 then begin
    !p.color = color_old
endif
If n_elements(thck) ne 0 then begin
    !p.thick = thick_old
endif
;
return
end
