;+
; NAME:  RESET
; PURPOSE:  Reset system variables to their startup, default values
;           structures re-initialized are: !X,!Y,!Z,!P,!MAP
;           By default, all are reset, or you may selectively turn them off
;           (see KEYWORDS)
; CATEGORY: Graphicsd Utility
; CALLING SEQUENCE:  RESET
; INPUTS:   none
; OPTIONAL INPUT PARAMETERS:  none
; KEYWORD PARAMETERS:   /NOX,/NOY,/NOZ       DON''T RESET !X,!Y,!Z RESPECTIVELY   
;                       /NOAXES              DON''T RESET ANY OF !X,!Y,!Z      
;                       /NOPLOT              DON''T RESET !P PARAMETERS        
;                       /NOMAP               DON''T RESET !MAP PARAMETERS      
;                       /HELP GIVES ABOVE INFORMATION                          
; OUTPUTS: none
; OPTIONAL OUTPUT PARAMETERS: none
; COMMON BLOCKS:  none
; SIDE EFFECTS:   resets system parameters to startup values
; RESTRICTIONS:   none known
; PROCEDURE:      Sets the system structures to pre-defined values
; MODIFICATION HISTORY: Hughes HIA/NRCC 19-MAY-1994 
;-

PRO RESET,NOX=NOX,NOY=NOY,NOZ=NOZ,NOPLOT=NOPLOT,NOMAP=NOMAP,NOAXES=NOAXES,HELP=HELP

if keyword_set(help) then begin

   print,'     +-------------------------------------------------------------------+'
   print,'     |RESET [,/NOX][,/NOY][,/NOZ][,/NOAXES][,/NOPLOT][,/NOMAP][,/HELP]   |'
   print,'     |                                                                   |'
   print,'     |THIS PROCEDURE RESETS ALL SYSTEM STRUCTURES TO THEIR STARTUP       |'
   print,'     |DEFAULTS UNLESS A PARTICULAR STRUCTURE IS FLAGGED BY THE           |'
   print,'     |FOLLOWING KEYWORDS                                                 |'
   print,'     |/NOX,/NOY,/NOZ       DON''T RESET !X,!Y,!Z RESPECTIVELY             |'
   print,'     |/NOAXES              DON''T RESET ANY OF !X,!Y,!Z                   |'
   print,'     |/NOPLOT              DON''T RESET !P PARAMETERS                     |'
   print,'     |/NOMAP               DON''T RESET !MAP PARAMETERS                   |'
   print,'     |                                                                   |'
   print,'     |IF NO KEYWORDS ARE SUPPLIED, THEN EVERYTHING IS RESET              |'
   print,'     |                                                                   |'
   print,'     |/HELP GIVES ABOVE INFORMATION                                      |'
   print,'     +-------------------------------------------------------------------+'
   return
endif

if keyword_set(nox) then do_x=0 else do_x=1 
if keyword_set(noy) then do_y=0 else do_y=1
if keyword_set(noz) then do_z=0 else do_z=1
if keyword_set(noaxes) then begin
   do_x=0 & do_y=0 & do_z =0
endif
if keyword_set(noplot) then do_p=0 else do_p=1
if keyword_set(nomap) then do_m=0 else do_m=1


XYZ$AXIS$$$ = $
      {!AXIS,TITLE: '',TYPE: 0L, STYLE: 0L, TICKS: 0L,TICKLEN: 0., THICK: 0., $
      RANGE: [0.,0.], CRANGE: [0.,0.], S: [0.,0.], MARGIN: [10., 3.], $
      OMARGIN: [0., 0.], WINDOW: [0.,0.], REGION: [0.,0.], CHARSIZE: 0., $
      MINOR: 0L, TICKV: FLTARR(30), TICKNAME: STRARR(30), GRIDSTYLE: 0L, $
      TICKFORMAT: ''}

PLT$PLT$$$ = $
      {!PLT, BACKGROUND: 255L, CHARSIZE: 0., CHARTHICK: 0., $
      CLIP: [0L, 0L, 639L, 511L, 0L, 0L], $
      COLOR: 0L, FONT: -1L, LINESTYLE: 0L, MULTI: [0L, 0L, 0L, 0L, 0L], $
      NOCLIP: 0L, NOERASE: 0L, NSUM: 0L, POSITION: LONARR(4), PSYM: 0L, $
      REGION: FLTARR(4), SUBTITLE: '', SYMSIZE: 0., T: FLTARR(4,4), $
      T3D: 0L, THICK: 0., TITLE: '', TICKLEN: .02, CHANNEL: 0L}

MAP$MAP$$$ = $
      {!MAP, PROFECTION: 0L, PHIOC: 0., P0LAT: 0., SINO: 0., COSO: 0., $
      SINR: 0., COSR: 0., SAT: FLTARR(6), OUT: FLTARR(12)}

if do_x then !x=xyz$axis$$$

if do_y then begin
   !y=xyz$axis$$$
   !y.margin=[4.,2.]
endif

if do_z then begin
   !z=xyz$axis$$$
   !z.margin=[0.,0.]
endif

if do_p then !p=plt$plt$$$

if do_m then !map=map$map$$$

return
end
