      PRO Yyyyddd2yymmdd, yr_, mt_, dy_, y_, m_, d_, e_, msg_

;+
; NAME:
;        YYYYDDD2YYMMDD.FOR
;
; PURPOSE:
;        To convert YYYYDDD to YYMMDD (from values to strings).
;
; CATEGORY:
;        Utility.
;
; CALLING SEQUENCE:
;        
;        Yyddd_To_Yymmdd, yr_,   Year value, 1986 < yr_ < 2086
;                         mt_,   Month value (should be zero)
;                         dy_,   Day value
;                         y_,    String of year
;                         m_,    String of month number
;                         d_,    String of day
;                         e_,    Error number
;                         msg_   String of error message
;
; INPUTS:
;        Data furnished by procedure arguments. No data entered at prompt.
;
; OPTIONAL INPUT PARAMETERS:
;        None.
;
; KEYWORD PARAMETERS:
;        None.
;
; OUTPUTS:
;        'yr_' has to be > 1986. Output contained in 'y_', 'm_' and 'd_'.
;        The value of 'e_' is 0 if successful; o.w.:
;
;        e_   msg_
;        --   ----
;         1   No date input.
;         2   No year entered.
;         3   Year is before 1986.
;         4   Invalid month value (>0) for conversion.
;         5   Day exceeds 365 (366) days.
;
; OPTIONAL OUTPUT PARAMETERS:
;        None.
;
; COMMON BLOCKS:
;        None.
;
; SIDE EFFECTS:
;        None.
;
; RESTRICTIONS:
;        None.
;
; PROCEDURE:
;        None.
;
; MODIFICATION HISTORY:
;        Created          4 June 1992             J. Trudel, CSA/Prologic
;           - Based on INPUT.PRO and CANOPUS.PRO
;        Modified         3 Dec. 1992           D.F. Tanguay
;           - Test for day number was incorrect (chg'd subscript from 11 -> 12)
;        Modified         5 Jan. 1993           D.F. Tanguay
;           - There was a bug when day number LE 31
;
;-

      d_in_mth = INTARR(12)
      leapy_d  = INTARR(12)
      dat      = INTARR(12)

      d_in_mth = [0,31,59,90,120,151,181,212,243,273,304,334,365]
      leap_d   = [0,31,60,91,121,152,182,213,244,274,305,335,366]
      yer = 0
      mth = 0
      day = 0

      y_ = ''
      m_ = ''
      d_ = ''
      msg_ = ''
      e_ = 0   ; Assumes input is appropriate for conversion

      IF (yr_ EQ 0) THEN BEGIN
         e_ = 2
         msg_ = 'No year entered'
         IF (dy_ EQ 0) THEN BEGIN
            e_ = 1
            msg_ = 'No date input'
         ENDIF
         RETURN
      ENDIF

      IF (yr_ LT 1986) THEN BEGIN
         e_ = 3
         msg_ = 'Year is before 1986'
         RETURN
      ENDIF

      IF (mt_ GT 0) THEN BEGIN
         e_ = 4
         msg_ = 'Invalid month value for [YY]YY,DDD conversion'
         RETURN
      ENDIF

      IF (4*(yr_/4) EQ yr_) THEN BEGIN
         dat = leap_d
         IF (dy_ GT dat(12)) THEN BEGIN
            e_ = 5
            msg_ = 'Day exceeds 366 days'
            RETURN
         ENDIF
      ENDIF ELSE BEGIN
         dat = d_in_mth
         IF (dy_ GT dat(12)) THEN BEGIN
            e_ = 5
            msg_ = 'Day exceeds 365 days'
            RETURN
         ENDIF
      ENDELSE

      in_loop = 1
      IF (dy_ LE dat(1)) THEN BEGIN
         day = dy_
         mth = 1
         in_loop = 0 ; don't go through next loop
      ENDIF

      c0 = 2
      WHILE (in_loop) DO BEGIN
         IF (dy_ GT dat(c0-1) AND dy_ LE dat(c0)) THEN BEGIN
            day = dy_ - dat(c0-1)
            mth = c0
            in_loop = 0
         ENDIF ELSE c0 = c0 + 1
      ENDWHILE

      IF (yr_ GE 2000) THEN yer = 2000 - yr_
      IF (yr_ LT 2000) THEN yer = yr_ - 1900
      IF (yer LE 9) THEN y_ = STRCOMPRESS( STRING( 0, yer), /REMOVE_ALL) ELSE $-
         y_ = STRCOMPRESS( STRING( yer), /REMOVE_ALL)
      IF (mth LE 9) THEN m_ = STRCOMPRESS( STRING( 0, mth), /REMOVE_ALL) ELSE $-
         m_ = STRCOMPRESS( STRING( mth), /REMOVE_ALL)
      IF (day LE 9) THEN d_ = STRCOMPRESS( STRING( 0, day), /REMOVE_ALL) ELSE $-
         d_ = STRCOMPRESS( STRING( day), /REMOVE_ALL)


      RETURN
      END
;
; EOF: YYYYDDD2YYMMDD.FOR
