;+
; NAME:
;       CADI_EXAMPLE
; PURPOSE:
;       Code to act as example of, and exercise all, CADI routines.
;       Display the code in 132 columns to see all the comments.
; CALLING SEQUENCE:
;       CADI_EXAMPLE
; KEYWORDS:
;       DIR = Scalar string naming the directory which contains the required
;          test files. If specified, it must include the terminating character
;          (e.g. ] or /). Default is the null string '', for the default
;          directory. E.g.: DIR='LON001$DKB0:[GRANT.IDL_TEST]'
;       PS: If present and non-zero, then the graphics is directed to B/W
;          PostScript files rather than the screen.
; SIDE EFFECTS:
;       Produces graphic output.
; RESTRICTIONS:
;       Requires the appropriate data files to be in
;          LON001$DKB0:[GRANT.IDL_TEST].
;       Takes about 20 minutes to run on a VAXstation.
; MODIFICATION HISTORY:
;       Ian Grant, UWO, 26 Oct 1994.
;       GRANT, 12 Jan 1995: Added keywords DIR and PS.
;       GRANT, 30 Jan 1995: Added CADI_IGSUMM and CADI_HTSUMM calls, and FILE
;          keywords to PROHARDCOPY calls.
;       JWM, 31 Mar 1995: added PCL keyword.
;       JWM, 4 Nov 1995: added PCN keyword to produce narrow portrait orient. plots.
;-

pro cadi_example, dir=dir, ps=ps,pcl=pcl,pcn = pcn

on_error, 2
if not keyword_set(dir) then dir = ''

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 1 ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; start with height-velocity plot (htv procedure)

; Read Gillam MD1 data (twice).
; Plot h't for 4 MHz in parallel with traces for velocity fitted to 4 MHz data.
; Frequencies in the file are: 2, 3, 4, 6 MHz.

;goto, htplot  ; skip this htv procedure
print, 'Doing #1, height-time velocity plot'
tr = cantime(1995, 01, 05, 00) + [0, 1*3600L]                                     ; Define 2-hour interval
print, tr
;stop
gil_ht   = cadi_read_dir(dir=dir, ext='MD1', timerange=tr, /tfh, /inf)  ; Read all freqs, ignoring Doppler info
;stop
print, 'first read done'
;gil_ht   = cadi_read_dir(dir=dir, ext='fht', timerange=tr, /tfh, /inf)          ; Read all freqs, ignoring Doppler info
;stop
; in below: for MD data frequency 0 was the lower, and 1 was the upper
gil_4mhz = cadi_read_dir(dir=dir, ext='MD1', timerange=tr, fr=[0,0], /inf ,htlimitmin = 0, htlimitmax = 510)
print, 'second read done'
; Read only 4 MHz, including Doppler info
;print, "here"
;gil_4mhz = cadi_read_dir(dir=dir, ext='fht', timerange=tr, fr=[0,0], /inf)      ; Read only 4 MHz, including Doppler info
vel = cadi_iq2vel( gil_4mhz )                                                   ; Convert 4 MHz IQ data to velocities
;vel_edit = cadi_vel_edit(vel, nsource=40, azi=20, hor=100, ver=15, /drop,htlimit=150); flag poor quality velocities as missing
;vel_edit = cadi_vel_edit(vel, nsource=10, azi=10000, hor=400, ver=100, /drop);, htlimit = 200)       ; Flag poor quality velocities as missing
vel_edit = cadi_vel_edit(vel, nsource=5, azi=10000, hor=400, ver=100, /drop)  ; Flag poor quality velocities as missing
if keyword_set(ps) then prohardcopy, /ps, file='C:\plotfiles(temp)\cadi_htv.ps'                    ; Direct plot to file if desired
;if keyword_set(ps) then prohardcopy, /ps, file='A:\cadi_htv.ps'                    ; Direct plot to file if desired
if keyword_set(pcl) then prohardcopy, /pcl, file='C:\plotfiles(temp)\cadi_htv.pcl'                    ; Direct plot to file if desired
;cadi_htv, gil_ht, vel=vel_edit, timer=tr, panel='fAHVNahv', fr=[1], ver = 200, /inf        ; Plot 4 Mhz h't and velocity
;stop
;cadi_htv, gil_ht, vel=vel_edit, timer=tr, panel='fXYV', fr=[1],hor = 500,ver = 150, /inf ,max_height = 510;, /dumpdata   ; Plot 4 Mhz h't and velocity
cadi_htv, gil_ht, vel=vel_edit, timer=tr, panel='fAHV', fr=[0], hor = 1000,ver = 150, /inf ,max_height = 510;, /dumpfile    ; Plot 4 Mhz h't and velocity
;cadi_htv, gil_ht, vel=vel_edit, timer=tr, panel='f', fr=[1,2,3,4],ver=150, /inf, max_height = 200;,/dumpdata        ; Plot 4 Mhz h't and velocity
;cadi_htv, gil_ht, vel=vel_edit, timer=tr, panel='fAHVNahv', fr=[1],hor = 1000, ver=200, /inf, max_height = 510
; , dumpfile = 'a:xyz.dat'        ; Plot 4 Mhz h't and velocity

time                                                                            ; Print user's name and timestamp on plot
if keyword_set(ps) then prohardcopy                                             ; Close plot file
if keyword_set(pcl) then prohardcopy                                             ; Close plot file

;cont_or_quit = reply_char('[C]ontinue or [Q]uit','cq','q')
;   if cont_or_quit eq 'Q' then return

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 2 ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
htplot:
goto, skymap ;skip this htplot section
; Read Resolute Bay FHT data.
; Plot h't for all three frequencies.
; Frequencies in the file are: 4, 3, 5 MHz.
print, 'Doing #2 height-time plot'
;tr = cantime(1995, 01, 05, 12) + [0, 12*3600L]                                    ; Define 1-hour interval
tr = cantime(2001, 12, 15, 15) + [0, 9*3600L]                                    ; Define 1-hour interval
;res_ht = cadi_read_dir(dir=dir, ext='fht', timerange=tr, /tfh, /inf)            ; Read h't info (no Doppler), all freqs
res_ht = cadi_read_dir(dir=dir, ext='md1', timerange=tr, /tfh, /inf,htlimit = 510)            ; Read h't info (no Doppler), all freqs
if keyword_set(ps) then prohardcopy, /ps, file='c:\plotfiles(temp)\cadi_ht3.ps'                    ; Direct plot to file if desired
if keyword_set(pcl) then prohardcopy, /pcl, file='c:\plotfiles(temp)\cadi_ht3.pcl'                    ; Direct plot to file if desired
if keyword_set(pcn) then prohardcopy, /pcn, file='c:\plotfiles(temp)\cadi_ht3.pcn'                    ; Direct plot to file if desired
;portrait                                                                        ; Set portrait plot orientation
;cadi_htv, res_ht, timer=tr, panel='fff', freq=[1,2,3], /inf, max_height = 510                     ; Plot h't for three freqs: 3, 4, 5 MHz
cadi_htv, res_ht, timer=tr, panel='ff', freq=[0,1], /inf, max_height = 200                     ; Plot h't for three freqs: 3, 4, 5 MHz
;stop
;cadi_htv, res_ht, timer=tr, panel='f', freq=[0], /inf, max_height = 510;, /dumph                     ; Plot h't for three freqs: 3, 4, 5 MHz
if keyword_set(ps) or keyword_set(pcl) then $
 begin
  time
 endif
                                                        ; Print user's name and timestamp on plot
if keyword_set(ps) or keyword_set(pcl) or keyword_set(pcn) then prohardcopy                                             ; Close plot file
;wait,5

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 3 ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
skymap:
goto, multiht ; skip this skymap section
print, 'Doing #3, skymaps'
; Read Resolute Bay FHT data for 4 MHz.
; Plot 4 MHz skymap for every tenth time.

;tr = cantime(1993, 11, 10, 7) + [0, 1*3600L]                                    ; Define 1-hour interval
tr = cantime(1995, 04, 06, 03) + [0, 1*3600L]                                    ; Define 1-hour interval
;res_4mhz = cadi_read_dir(dir=dir, ext='fht', timerange=tr, fr=[0,0], /inf)      ; Read Doppler info for 4 MHz, same hour
;res_4mhz = cadi_read_dir(dir=dir, ext='md1', timerange=tr, fr=[0,0], /inf)      ; Read Doppler info for 4 MHz, same hour
res_4mhz = cadi_read_dir(dir=dir, ext='md1', timerange=tr, fr=[0,0], /inf)      ; Read Doppler info for 4 MHz, same hour
res_4mhz_kvec = cadi_xap2kvec( cadi_iq2xap( res_4mhz )) ; Convert 4 MHz IQ data to k-vectors
;stop
dummy = cadi_tblocks(res_4mhz_kvec.data, ntimes=tcount)                         ; How many times have data for a skymap?
print, tcount                                                                   ; 112. So we'll plot times 0,10,...,110.
if keyword_set(ps) then prohardcopy, /ps, file='c:\plotfiles(temp)\cadi_sky.ps'                    ; Direct plot to file if desired
if keyword_set(pcl) then prohardcopy, /pcl, file='c:\plotfiles(temp)\cadi_sky.pcl'                    ; Direct plot to file if desired
if keyword_set(pcn) then prohardcopy, /pcn, file='c:\plotfiles(temp)\cadi_sky.pcn'                    ; Direct plot to file if desired
landscape                                                                       ; Set landscape plot orientation
if keyword_set(ps) then $
;cadi_skymaps, res_4mhz_kvec, fstep=2,ncols=6,nrows=5,timex=4*lindgen(30), $    ; Plot 12 skymaps in a 3*4 grid
cadi_skymaps, res_4mhz_kvec, /overplot, fstep=2,ncols=1,nrows=1,timex=5*lindgen(12), $    ; Plot 12 skymaps in a 3*4 grid
/nocolor, axismax = 1.0,    pos_regions = [0.08,-1,0.75,0.95] $
else if keyword_set(pcl) then $
cadi_skymaps, res_4mhz_kvec, fstep=2,ncols=4,nrows=3,timex=10*lindgen(12), $    ; Plot 12 skymaps in a 3*4 grid
/nocolor, /pcl $
else $
cadi_skymaps, res_4mhz_kvec, /overplot, fstep=2,ncols=1,nrows=1,timex=5*lindgen(12), $   ; Plot 12 skymaps in a 3*4 grid
/nocolor, axismax = 1.0,    pos_regions = [0.08,0.1,0.75,0.95]

time                                                                            ; Print user's name and timestamp on plot
if keyword_set(ps) then prohardcopy                                             ; Close plot file
if keyword_set(pcl) then prohardcopy                                            ; Close plot file
wait, 5
print, "skymaps done"

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 4 ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
multiht:
goto, ionograms ;skip this section
print, 'Doing #4, height-time plot for entire day'
; Generate h't summary plot for Eureka, 16 Feb 1994 (partial only)

if keyword_set(ps) then prohardcopy, /ps, file='c:\plotfiles\cadi_hts.ps'                    ; Direct plot to file if desired
if keyword_set(pcl) then prohardcopy, /pcl, file='c:\plotfiles\cadi_hts.pcl'                    ; Direct plot to file if desired
cadi_htsumm, dir=dir, datestr='950406', ext='MD1', freqx=0, /inform
if keyword_set(ps) or keyword_set(pcl) then prohardcopy                                             ; Close plot file

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 5 ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
ionograms:
; Generate ionogram summary plot for Eureka, 16 Feb 1994 (partial only)
goto, htfplots ;skip this section
print,'Doing #5, Ionograms'
if keyword_set(ps) then prohardcopy, /ps, file='c:\plotfiles(temp)\cadi_igs.ps'              ; Direct plot to file if desired
if keyword_set(pcl) then prohardcopy, /pcl, file='c:\plotfiles(temp)\cadi_hf.pcl'              ; Direct plot to file if desired
cadi_igsumm, dir=dir, datestr='931208', ext='ffi', /inform, heightrange = [0,510];,$
  ;part_day = 4, thour = 22;, eldensityrange = [0,5.0e12];, /hourly
;part_day = 4 gives 3x5 panels, part_day = 1 gives
if keyword_set(ps) or keyword_set(pcl)then prohardcopy                                             ; Close plot file
wait, 5

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 6 ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
htfplots:
; Generate ionogram summary plot for Eureka, 16 Feb 1994 (partial only)
goto, diffhtplot ;skip this section
print,'Doing #6, height-time-allfrequency plot'
tr = cantime(1994, 11, 09, 22) + [0, 1*3600L]                                    ; Define 1-hour interval
if keyword_set(ps) then prohardcopy, /ps, file='d:\plotfiles(temp)\cadi_htf.ps'              ; Direct plot to file if desired
if keyword_set(pcl) then prohardcopy, /pcl, file='d:\plotfiles(temp)\cadi_htf.pcl'              ; Direct plot to file if desired
cadi_htfsumm, dir=dir, timerange=tr, ext='MD2', /inform, /contour, $
    heightrange = [0,150],freqrange = [0,10.0e6];, /mps
if keyword_set(ps) or keyword_set(pcl) then prohardcopy                                             ; Close plot file
;wait, 5
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; 7 ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
diffhtplot:
goto, endofprogram ;skip this diffhtplot section
; Plot h't for several frequencies.
;print, 'Doing #7 contour-height-time-frequency plot'
;tr = cantime(1994, 11, 05, 0) + [0, 1*3600L]                                    ; Define 1-hour interval
;res_ht = cadi_read_dir(dir=dir, ext='md2', timerange=tr, /tfh, /inf)            ; Read h't info (no Doppler), all freqs
;stop
;if keyword_set(ps) then prohardcopy, /ps, file='d:\plotfiles(temp)\cadi_ht3.ps'                    ; Direct plot to file if desired
;if keyword_set(pcl) then prohardcopy, /pcl, file='d:\plotfiles(temp)\cadi_ht3.pcl'                    ; Direct plot to file if desired
;cadi_htv, res_ht, timer=tr, panel='fff', freq=[2,0,1], /inf                     ; Plot h't for three freqs: 3, 4, 5 MHz
;cadi_htv, res_ht, timer=tr, panel='ff', freq=[0,1], /inf, max_height = 510                     ; Plot h't for three freqs: 3, 4, 5 MHz
;cadi_contour_htf, res_ht, timer=tr, /inf, max_height = 150;                 ; Plot h't for three freqs: 3, 4, 5 MHz
;if keyword_set(ps) or keyword_set(pcl) then $
; begin
;  time
; endif
                                                        ; Print user's name and timestamp on plot
;if keyword_set(ps) or keyword_set(pcl) or keyword_set(pcn) then prohardcopy                                             ; Close plot file
;wait,5
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
endofprogram:
print, "end"
return
end
