function w_avg, inarr, yrange, thresh		;weighted averaging

sumw = 0
sumwh = 0
sumi = 0
for i = 0,yrange - 1 do begin
  wt = abs(inarr(i))
  if wt gt thresh then begin		;only accept data above threshold
    wtt = 10.0^(wt/70.0)			;convert back from dB to power (db values were x7 for use by colorscale)
    wtt = wtt^3						;weight peaks more heavily
    sumw = sumw + wtt
    sumwh = sumwh + i*wtt
    sumi = sumi + 1
  endif
endfor
;stop
if sumi ne 0 then return, sumwh/sumw else return, 0
end



;+
; NAME:
;       CADI_IGWMAP
; PURPOSE:
;       Map ionograms onto vertical and horizontal planes.
; CALLING SEQUENCE:
;       CADI_IGWMAP, DIR=DIR, DATESTR=DATESTR, EXT=EXT
; INPUTS:
;       DIR = Scalar string containing directory in which data is located.
;          Syntax ready to prepend onto filename e.g. 'D:\CADIDATA\'.
;          Default is ''.
;       DATESTR = string holding date of data as 6 ASCII digits YYMMDD.
;          Default is to take date from header of first .ext file in directory.
;       EXT = scalar string containing extension of data files, without period.
;          Default is 'MD0'.
;		THOUR = gives starting hour for the ionograms (if cnatimein it is derivedfrom the cantime)
;		HEIGHTRANGE = 2 element array giving min height and max height
;		CANTIMEIN = 2 element array of type Cantime giving beginning and end of plottimes
;		COLOUR = if set, plots in color
;		XRANGE = range of plot scale
;       SHOW = 0 color shows dB, = 1 color shows frequency
;       PCHOICE = 0 plot height versus EW position, =1 plot height versus NS position, =2 plot NS versus EW positions
; KEYWORD PARAMETERS:
;       INFORM: If present and nonzero, progress messages are printed.
;       ERROR = integer scalar. Returned as true if an error occurred, else
;          false.
; SIDE EFFECTS:
;       Generates a plot file (not implemented).
; MODIFICATION HISTORY:
;       JWM 4 April 2004 program is based on Ian Grant's cadi_igsumm.
;-

pro cadi_igwmap, dir=dir, datestr=datestr_in, ext=file_ext, $
   inform=inform, error=error, heightrange = heightrange,$
    cantimein = cantimein, colour = colour, xrange = xrange, show = show, pchoice = pchoice

on_error, 0 ;2

psav = !p
xsav = !x
ysav = !y

showposition = !false
doplotfile = !false
if not keyword_set(file_ext) then print, 'no file extension spaecified'
if not keyword_set(dir) then dir = ''

; Get header information (CADI_READ_DIR get it from first file)

h = cadi_read_dir(dir=dir, ext=file_ext, /onlyheader, error=error )
if error then begin
   error_message = 'Error reading first file for header information'
   goto, error_return
   endif
if h.nantennas ne 4 then begin
 print, "******************  must have 4 antenna data for mapping ********************************"
 goto, error_return
endif
; Input date from keyword or from first file

if not keyword_set(cantimein) then begin
  if not keyword_set(datestr_in) then $
   candate = canmidnight(h.time) $   ; Date from time in first file
  else begin
   datestr = datestr_in ; Unnecessary?
   reads,datestr,year,month,day,format='(3i2)'       ; Date from keyword
   if year lt 54 then year = year + 100        ;y2k adjustment
   ;print, 'doing timecalc'
   candate=cantime(1900+year,month,day,0,0,0)
   ;print, 'done'
   endelse
; Get DAYNUM for plot title

  civil_time, year, month, day, daynum, hour, minute, second, can_time = candate

endif else begin   ;yes there is cantimein
     cantimeset = cantimein
     civil_time, year, month, day, daynum, starthour, minute, second, cantimein(0)
     sthr = starthour
     noofhours = (cantimeset(1) - cantimeset(0))/3600L
;print, 'noofhours = ',noofhours
     ;endhr = sthr + noofhours - 1
endelse
;stop

rx = 0L         ; Index of receiver to be plotted
mhzrange = [1.0,20.0]
tdiff = h.dtime/60		;tdiff is  (for scaling) just the time increment (in minutes) between ionograms
;print, 'tdiff = ',tdiff
!p.noerase = 1
!p.ticklen = 0.04
charsize = 0.8
;stop

def_ticknames = replicate('',20)

   !p.background = 255b		;white
   back_color = 255b
   !p.color = 0				;black
   fore_color = 0b
erase

prev_timex = -1
prev_panelx = -1

htmin = 0
if keyword_set(heightrange) then htmin = heightrange(0)
if dir eq "md4" then htmax = 1020 else htmax = 510
if keyword_set(heightrange) then htmax = heightrange(1)
;stop

cadi = cadi_read_dir(dir=dir, timerange = cantimeset,$ ;timerange=timerange_hour, $
    ext=file_ext, tfh= 0, error=read_error, inf=keyword_set(inform), htlimitmax=htmax, htlimitmin = htmin )
if read_error then begin
    message, /inform, $
      'Error reading data in time range '+strcanrange(timerange_hour)
    goto, end_hourx_loop
endif
;next get k vectors for thew ionogram data
cadi_kvec = cadi_xap2kvec( cadi_iq2xap( cadi))

if not cadi.header_exists then goto, end_hourx_loop      ; No soundings for this hour

   h = cadi_kvec.header
   d = cadi_kvec.data
   ;structure of d: x [t,f,h,d], dB (source power) float, k array 3 [Kx(ew),Ky(ns),Kz(up) float]
;stop
site = cadi_site(h.site, h.time)

if not keyword_set(xrange) then xrange = 400

;start plotting
usersym, [-1.0,1.0,1.0,-1.0,-1.0],[-1.0,-1.0,1.0,1.0,-1.0],/fill
htimex = 0
minfno = 0
maxfno = h.nfreqs - 1


startplotpanels:


  erase
  civil_time, year, month, day, daynum, hour, minute, second, h.times(htimex)
  timex = round( (60*(hour-sthr)+minute) / tdiff )		;get index of ionogram plot
  hrange = ends(h.heights)
  if keyword_set(heightrange) then hrange = heightrange
  if hrange(1) gt htmax then hrange(1) = htmax


 ;put on boxes for use by mouse
  plot,[0],[0],psym = 8, symsize = 4, color = 240,/device,/noerase, xstyle = 4, ystyle = 4,position = [80,20,120,60]
  xyouts,  10,20, 'Done', color = 240,/device, charsize = 2
  plot,[0],[0],psym = 8, symsize = 4, color = 50,/device,/noerase, xstyle = 4, ystyle = 4,position = [300,20,350,60]
  plot,[0],[0],psym = 8, symsize = 4, color = 50,/device,/noerase, xstyle = 4, ystyle = 4,position = [450,20,500,60]
  xyouts, 100,20, 'step: forward 10', color = 50,/device, charsize = 2
  xyouts, 330,20, 'forward 1', color = 50, /device, charsize = 2
  plot,[0],[0],psym = 8, symsize = 4, color = 130,/device, /noerase, xstyle = 4, ystyle = 4,position = [580,20,630,60]
  plot,[0],[0],psym = 8, symsize = 4, color = 130,/device, /noerase, xstyle = 4, ystyle = 4,position = [700,20,750,60]
  xyouts, 500,20, 'back 1', color = 130, /device, charsize = 2
  xyouts, 600,20, 'back 10', color = 130, /device, charsize = 2
  plot, [0], [0], psym = 8, symsize = 4, color = 200, /device,/noerase, xstyle =4, ystyle = 4, position = [900,20,950,60]
  xyouts, 810, 20, 'plotfile',color = 200,/device,charsize = 2


if doplotfile eq !true then begin
  loadct, 0
  set_plot, 'ps'
  device, /landscape, filename = 'c:\plotfiles(temp)\igrmmap.ps'
endif

;put on color scale
  if show eq 0 then begin						;color shows dB
    yticklabels = ['0','10','18','26','34','42','50']
    plot, [0,1],[0,1],/nodata, yrange = [0,256], ystyle = 1, xrange = [0,1],$
     position = [0.97,0.18,0.99,0.85], xstyle = 4, yticks = 6, ytickname = yticklabels, title = 'dB'
    for c = 0,255 do oplot, [0,1],[c,c],color = 255 - c, thick = 3
  endif else begin  							;color shows frequency
      yticklabels = strarr(6)
    for s = 0,5 do begin
      f_n = round(float(maxfno - minfno)*s/(5*2)) + minfno		;note freq scale set for lower 1/2 of freqs
      f = h.freqs(f_n)/1.0e6
      yticklabels(s) = string(format = '(f4.1)', f)
    endfor
    plot, [0,1],[0,1],/nodata, yrange = [0,256], ystyle = 1, xrange = [0,1],$
     position = [0.96,0.18,0.99,0.85], xstyle = 4, yticks = 5, ytickname = yticklabels, title = 'freq, MHz'
    for c = 0,255 do oplot, [0,1],[c,c],color = 255 - c, thick = 3
  endelse

if pchoice eq 0 then begin
   y_range = hrange
   xtitle = '<- W  distance, km   E ->'
   ytitle = 'km'
endif
if pchoice eq 1 then begin
   y_range = hrange
   xtitle = '<- S  distance, km   N ->'
   ytitle = 'km'
endif
if pchoice eq 2 then begin
   y_range = [-xrange,xrange]
   xtitle = '<- W  distance, km   E ->'
   ytitle = '<- S  distance, km   N ->'
endif

plot, /nodata,/noerase, [0], [0], position = [0.2, 0.15, 0.8, 0.94],xtitle = xtitle , ytitle = ytitle,$
     xrange= [-xrange,xrange], xstyle=1, yrange= y_range, ystyle=1, xtickname = def_ticknames, ytickname = def_ticknames,$
     xthick = 2, ythick = 2, charsize = 2, charthick = 2;, $
        ;title= h.site + " Ionogram Map of frequency" + strcantime(/date,cantimeset(0)), ymargin = [100,100],/noclip


;show last cursor read position if available
if showposition eq !true then begin
  xyouts,20 ,300 ,string(format = '(a,f5.0)','x position = ',xcurs), charsize = 1.5, /device
  xyouts,20 ,250 ,string(format = '(a,f5.0)','y position = ',ycurs), charsize = 1.5, /device
  oplot,[xcurs],[ycurs], psym = 2
  showposition = !false
endif

;openw, 1, 'c:/cdata/0l100435.pos'
  maxpowdb = 0
  if cadi_kvec.ndata gt 0 then begin          ; Any echoes in this hour?
    w = where(d.x.t eq htimex, wcount)  ; Any echoes for this time?
    if wcount gt 0 then begin
      d_ionogram = d(w)
      for p = 0,n_elements(d_ionogram)-1 do begin
      Kx = d_ionogram(p).k(0)
      Ky = d_ionogram(p).k(1)
      Kz = d_ionogram(p).k(2)
      if Kz lt 0 then begin
        Kz = -Kz
        Kx = -Kx
        Ky = -Ky
      endif
      Kh = sqrt(Kx^2 + Ky^2)
      zangle = atan(Kh,Kz)
      zangleEW = atan(Kx,Kz)
      zangleNS = atan(Ky,Kz)
      range = 3.0*float(d_ionogram(p).x.h)
      zpos = cos(zangle)*range
      xpos = tan(zangleEW)*zpos
      ypos = tan(zangleNS)*zpos
;if hour eq 4 and minute eq 35 and finite(xpos) then begin
;     if xpos lt -282 then begin
;       print, 'frequency =',h.freqs(d_ionogram(p).x.f), ' EW zenith angle = ',zangleEW,$
;        ' range = ', range, ' v height = ', zpos, ' v dist = ', xpos
;       printf, 1, string(format = '(e12.2,f8.3,3f8.1)',h.freqs(d_ionogram(p).x.f),zangleEW, range, zpos, xpos)
;     endif
;endif

      if pchoice eq 0 or pchoice eq 2 then xp = xpos else xp = ypos
      if pchoice eq 0 or pchoice eq 1 then yp = zpos else yp = ypos
     if (pchoice eq 0 and abs(ypos) lt 100) or (pchoice eq 1 and abs(xpos) lt 100) or (pchoice eq 2) then begin ;make sure echoes are in 100km slot
       if show eq 0 then begin					;color shows dB
         powdb5 = 5.0*d_ionogram(p).db
         if powdb5 gt 255 then powdb5 = 255
         oplot, [xp], [yp],psym = 8, $									;do the plotting
              color = 255 - powdb5, symsize = float(powdb5)/255 + 0.2
       endif else begin							;color shows frequency
         pcolor = (d_ionogram(p).x.f - minfno)* (255/(maxfno - minfno)*2)   ;set scale for lower freq using *2
         if (pcolor gt 255) then pcolor = 255
;print,'count =',p, ' zenithangle = ',zangleEW,' range = ',range,' power =', powdb6
         oplot, [xp], [yp],psym = 8, $									;do the plotting
             color = 255 - pcolor
       endelse
     endif ;in 100 km slot
        ;put value into igrmarr
  ;      igrmarr( d_ionogram(p).x.f,fix((float(ypos)-hrange(0))/3)) = maxpowdb
      endfor

            ; Write time on ionogram map
hhmm_str = string(hour,':', minute, format='(i2.2,a,i2.2)')
if pchoice lt 2 then ylocate = 50 else ylocate = -xrange + 50
xyouts, -xrange +25, ylocate, '!c'+hhmm_str, charsize = 3, charthick = 2


;close, 1

    endif ; wcount gt 0
  endif ; cadi.ndata gt 0
;have finished plotting the ionogram

if doplotfile eq !true then begin
  device, /close
  doplotfile = !false
  loadct, 39
  set_plot, 'win'
  !p.background = 255
  !p.color = 0
  goto, startplotpanels
endif

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;MOUSE CLICKS ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ;next get mouse click for what to do
  CURSOR, x, y, /DEVICE, /down
  ;print, 'cursor clicked at ',x,',',y

  if (abs(x - 85) le 15) and (abs(y - 27) le 15) then begin		;Done clicked
     close, /all
     return
  endif

if (abs(x - 308) le 15) and (abs(y - 27) le 15) then begin  	;step forward 10
    htimex = htimex + 10
    if (htimex gt h.ntimes-1) then htimex = h.ntimes -1
  endif

  if ((abs(x - 458) le 15) and (abs(y - 27) le 15)) then begin		;step forward 1
     htimex = htimex + 1
  endif

  if ((abs(x - 587) le 15) and (abs(y - 27) le 15)) then begin 		;step back 1
     htimex = htimex - 1
  endif

  if ((abs(x - 706) le 15) and (abs(y - 27) le 15)) then begin		;step back 10
  htimex = htimex -10
    if (htimex lt 0) then htimex = 0
  endif

if htimex eq h.ntimes then return									;at end so go to calling bprogram

  if ((abs(x - 905) le 15) and (abs(y - 27) le 15)) then doplotfile = !true		;do plotfile procedure

;click on plot to read coordinates
if x gt 205 and x lt 816 and y gt 92 and y lt 584 then begin
  cursor, xcurs, ycurs, /nowait, /data	 	;read cursor position in data coordinates
  showposition = !true
endif

goto, startplotpanels

;endtimex:
 ;endfor ; timex
   end_hourx_loop:
  ;; endfor ; hourx


!p.noerase = 0
!p = psav
!x = xsav
!y = ysav

error_return:
return

end
