;+
; NAME:
;	ACF
; PURPOSE:
;	Return autocorrelation function.
;	The autocorrelation function is the normalized autocovariance function.
; CALLING SEQUENCE:
;	Result = ACF(X)
; INPUTS:
;	X = vector. Timeseries.
; KEYWORD PARAMETERS:
;	MAXLAG = Number of maximum lag for which acf is returned.
; OUTPUTS:
;	Result = vector of autocorrelation coefficients for
;		lags 0, 1, ..., MAXLAG. Result(i) is for lag i.
; PROCEDURE:
;	Calls IMSL_CCF with data vector repeated.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 11 Oct 1990: Written in IDL1.
;	IFG, 7 Feb 1991: Converted to IDL2.
;	IFG, 7 Feb 1991: Changed MAXLAG from parameter to keyword.
;	IFG, 23 Jul 1991: Renamed CCV variable to CCV1 to avoid conflict with 
;	   CCV function name.
;	IFG, 23 Jul 1991: Changed text of MESSAGEs.
; 	IFG, 4 Jan 1993: Added ON_ERROR.
;-

function acf, x, maxlag=maxlag

on_error, 2
nobs = n_elements(x)
if nobs lt 1 then message, 'X has too few elements'
if not keyword_set(maxlag) then maxlag = nobs-1
if (maxlag lt 1) or (maxlag ge nobs) then $
   message, 'Must have 1 <= MAXLAG < NOBS'
y = x
iprint = 0
iseopt = 0
imean = 1

imsl_ccf, nobs,x,y,maxlag,iprint,iseopt,imean,xmean,ymean,xvar,ccv1,cc,secc

return, cc(maxlag:*)

end
