;+
; NAME:
;	CANJAN0
; PURPOSE:
;	CANOPUS time of preceding January 0.0.
;	Returns CANOPUS time of January 0.0 in year of the given CANOPUS time.
;	e.g. If CT is the CANOPUS time for 0200 UT on 1 January, then
;	CT - CANJAN0(CT) is equal to the number of seconds in 1 day and 2 hours.
;	Useful for labelling date/time axes. January 0.0 = 0000 hours at the
;	start of 31 December of the previous year.
; CALLING SEQUENCE:
;	Result = CANJAN0(CAN_TIME)
; INPUTS:
;	CAN_TIME = Scalar CANOPUS time.
; OUTPUTS:
;	Result = Long integer CANOPUS time of January 0.0.
; PROCEDURE:
;	Calls CIVIL_TIME to get year, then calls CANOPUS_TIME.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 9 May 1990.
;	IFG, 6 May 1991: Verified routine runs under IDL2.
;	IFG, 8 Nov 1991: Renamed from CAN_JAN0 to CANJAN0.
;	IFG, 24 Jul 1992: Added ON_ERROR.
;-

function canjan0, can_time

on_error, 2
civil_time,year,month,date,day,hour,minute,second,can_time
canopus_time, year,1,1,0,0,0,canjan1,ct_error	; Jan 1.0 (00:00 at start Jan 1)
return, canjan1 - 86400
end
