;+
; NAME:
;	CANTIME
; PURPOSE:
;	CANOPUS time from YEAR,MONTH,DATE,HOUR,MINUTE,SECOND.
; CALLING SEQUENCE:
;	Result = CANTIME(YEAR,MONTH,DATE,HOUR,MINUTE,SECOND [,ERROR])
; INPUTS:
;	YEAR,MONTH,DATE,HOUR,MINUTE,SECOND = Scalar integers.
;	Trailing parameters may be omitted and default to values taken from
;	1986-JAN-01 00:00:00.
; OPTIONAL INPUT PARAMETERS:
;	ERROR = Scalar integer.
;	   If ERROR is present then always return, with error status in ERROR.
;	   If ERROR is absent then stop if and only if an error occurs.
; OUTPUTS:
;	Result = LONG scalar CANOPUS time.
; OPTIONAL OUTPUT PARAMETERS:
;	ERROR = Scalar integer. Returns error status from CANOPUS_TIME.
; PROCEDURE:
;	Calls procedure CANOPUS_TIME.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRC, 1991 Apr 8, IDL2.
;	IFG 6 Sep 1991: Added ERROR parameter.
;	IFG 8 Nov 1991: Renamed from CAN_TIME to CANTIME.
;	IFG 24 Jul 1992: Allowed defaults for trailing parameters.
;		Added ON_ERROR.
;-

function cantime, year,month,date,hour,minute,second, error

;stop
on_error, 2
np = n_params()
if np lt 6 then second = 0
if np lt 5 then minute = 0
if np lt 4 then hour   = 0
if np lt 3 then date   = 1
if np lt 2 then month  = 1
if np lt 1 then year   = 1986

canopus_time, year,month,date,hour,minute,second,can_time_out,ct_error
if np eq 7 then $
   error = ct_error $
else $
   if ct_error ne 0 then begin
      ;stop
      message, 'Error in CANOPUS_TIME'

   endif


return, can_time_out
end
