;+
; NAME:
;	CIRCULAR_RANGE
; PURPOSE:
;	Shift values to lie within a circular range, e.g. into 0 to 360.
; CALLING SEQUENCE:
;	Result = CIRCULAR_RANGE( x, range )
; INPUTS:
;	X = Input numerical vector of values to be shifted.
;	RANGE = 2-element numerical vector specifying range in which elements
;	   of Result must lie. Examples for angles are RANGE = [0, 2*!pi],
;	   [0, 360], or [-180, 180].
; OUTPUTS:
;	Result = Output vector with length of X.
;	   Result(i) is X(i) with an integral multiple of RANGE(1) - RANGE(0)
;	   added so it lies between RANGE(0) and RANGE(1).
; PROCEDURE:
;	Shift by RANGE(0), call POSMOD, shift back by RANGE(0).
; MODIFICATION HISTORY:
;	GRANT, UWO, 26 May 1994: Written.
;-

function circular_range, x, range

return, posmod(x-range(0), range(1)-range(0)) + range(0)
end
