;+
; NAME:
;	ENDS
; PURPOSE:
;	Return first and last elements of a vector, optionally extending range.
;	Optionally extend range of a numeric vector by a fraction of the
;	increment between elements of X.
; CALLING SEQUENCE:
;	Result = ENDS(X)
; INPUTS:
;	X = Vector or scalar of any type.
; KEYWORD PARAMETERS:
;	EXTEND_CELL = Scalar real. Fraction of X increment by which to extend 
;	   range of Result. Useful as coordinates of edges of pixels centered
;	   on X(i).
; OUTPUTS:
;	Result = 2-element vector. Type is that of X*EXTEND_CELL.
;	   Contains first and last elements of X, if EXTEND_CELL is not set.
;	   If EXTEND_CELL is set and X is numeric then
;	   Result(0) = 
;	      (First element of X) - EXTEND_CELL*(increment between X elements)
;	   Result(1) = 
;	      (Last element of X) + EXTEND_CELL*(increment between X elements)
; RESTRICTIONS:
;	The increment in X is assumed constant.
; PROCEDURE:
;	The increment in X is assumed constant. The difference between the
;	first two elements is used to calculate the extension at both ends.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 28 Aug 1991, IDL2.
;	IFG, 22 Dec 1992: Added ON_ERROR.
;-

function ends, x, extend_cell=extend_cell

on_error, 2
result = [ x(0), x(n_elements(x)-1) ]
if keyword_set(extend_cell) and numerictype(x) then begin
   if n_elements(x) eq 1 then $
      inc = extend_cell $	; Take "spacing of X elements" to be 1.
   else $
      inc = extend_cell * (x(1)-x(0))
   result = result + [-inc, inc]
   endif
return, result
end
