;+
; NAME:
;	ENTERDEF
; PURPOSE:
;	Print prompt and default value then get interactive input with ENTER.
; CALLING SEQUENCE:
;	Result = ENTERDEF( TYPE, PROMPT, DEFAULT )
; INPUTS:
;	TYPE	= String describing data type to be entered.
;	PROMPT	= String containing prompt, without default value.
;	DEFAULT	= Default for value to be entered. Can be an expression, or a
;		  string containing an expression thus allowing the default
;		  expression to be appended to the prompt.
; OPTIONAL INPUT PARAMETERS:
;	HELP_STRING = As for ENTER.
; OUTPUTS:
;	Result = Returned value of desired type.
; OPTIONAL OUTPUT PARAMETERS:
;	EXIT_FLAG   = As for ENTER.
; PROCEDURE:
;	Appends default to prompt string and calls ENTER.
; MODIFICATION HISTORY:
;	Last modified 18 Apr 1991, Ian Grant, HIA/NRC, IDL2.
;	IFG, 22 Dec 1992: Added ON_ERROR.
;-

function enterdef, type,prompt,default,exit_flag,help_string

on_error, 2

; Append string form of default to prompt.
; DEFAULT should already be a string if TYPE eq 'STRING'.

if (datatype(default) eq 'STR') then $
   default_str = default $
else $
   default_str = strim(default)
promptdef = prompt + ' [' + default_str + ']'

; Form default value to send to ENTER

if (strupcase(type) ne 'STRING') and (datatype(default) eq 'STR') then begin
   if not execute('default_new = ' + default) then $
      message, 'Cannot evaluate expression in string DEFAULT'
   endif $
else $
   default_new = default

return, enter(type, promptdef, default_new, exit_flag, help_string)
end
