;+
; NAME:
;	FITQUADR
; PURPOSE:
;	Fit a quadratic polynomial to three points.
; CALLING SEQUENCE:
;	FITQUADR(X_IN, Y_IN, A_OUT, B_OUT, C_OUT [,X0_OUT [,Y0_OUT]] )
; INPUTS:
;	X_IN = Vector of x values of three points.
;	Y_IN = Vector of y values of three points.
; OUTPUTS:
;	A_OUT, B_OUT, C_OUT = scalar coefficients of quadratic through the 3
;	   points:
;		Y(i) = A_OUT*X(i)^2 + B_OUT*X(i) + C_OUT, for i=0,1,2.
; OPTIONAL OUTPUT PARAMETERS:
;	X0_OUT, Y0_OUT = x and y coordinates of the vertex of the parabola 
;		defined by the quadratic.
; PROCEDURE:
;	Inputs and outputs are single precision but calculations are double 
;	precision.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 16 Oct 1990: Converted to IDL1 from FORTRAN program
;		written at La Trobe University.
;	IFG  6 Feb 1991:  Converted to IDL2.
;	IFG, 5 Jan 1993: Added ON_ERROR.
;-

pro fitquadr, x_in,y_in,a_out,b_out,c_out,x0_out,y0_out

on_error, 2
if (n_elements(x_in) ne 3) or (n_elements(y_in) ne 3) then $
   message, 'FITQUADR error: Must have exactly 3 X and 3 Y values'
x = double(x_in)
y = double(y_in)

; Fit a parabola through the three points (from TJM)

a1=x(1)-x(0)
b1=x(2)-x(0)
alpha=y(1)-y(0)
beta=y(2)-y(0)
aa=-(a1*beta-b1*alpha)/(a1*b1*(a1-b1))
bb=(a1^2*beta-b1^2*alpha)/(a1*b1*(a1-b1))
a=aa
b=bb-2.0*aa*x(0)
c=aa*x(0)^2-bb*x(0)+y(0)

; Coordinates of vertex of quadratic

x0 = -b/(2*a)
y0 = a*x0*x0 + b*x0 + c

a_out = float(a)
b_out = float(b)
c_out = float(c)
x0_out = float(x0)
y0_out = float(y0)

return
end
