;+
; NAME:
;	GETWRD
; PURPOSE:
;	Return the N'th word (item).
; CATEGORY:
;	Text processing.
; CALLING SEQUENCE:
;	item = GETWRD(text,n,m)
; INPUTS:
;	text = a text string.
;         n = word to get.  If out of range returns a null string.
;	  If n<0 then returns text starting at word abs(n) to end of string.
; OPTIONAL INPUT:
;	m = number of last word to return (def = n).
; OUTPUT:
;	item = Returned item.
; PROCEDURE:
;	Make a vector indicating whether each char is a space:
;            0=no, 1=yes.  Do vector manipulations do find loc and len.
; MODIFICATION HISTORY:
;	Ray Sterner,  6 Jan, 1985.
;	         Johns Hopkins University Applied Physics Laboratory.
;           (FROM AN IDL1 USER LIBRARY)
;	Ian Grant, UWO, 21 Jan 1993: No changes needed for IDL2.
;	   Added ON_ERROR.
;-

FUNCTION GETWRD,TXTSTR,NTH,MTH   ; text,item # (first=0),last_word.

	ON_ERROR, 2
	IF N_PARAMS(0) LT 3 THEN MTH = NTH
	TST = 32B				; delimiter is space.
	X = BYTE(TXTSTR) NE TST
	X = [0,X,0]

	Y = (X-SHIFT(X,1)) EQ 1
	Z = WHERE(SHIFT(Y,-1) EQ 1)
	Y2 = (X-SHIFT(X,-1)) EQ 1
	Z2 = WHERE(SHIFT(Y2,1) EQ 1)

	NWDS = TOTAL(Y)
	LOC = Z
	LEN = Z2 - Z - 1

	N = ABS(NTH)
	IF N GT NWDS-1 THEN RETURN,''
	IF NTH LT 0 THEN GOTO, NEG
	IF MTH GT NWDS-1 THEN MTH = NWDS-1

	RETURN, STRMID(TXTSTR,LOC(N),LOC(MTH)-LOC(NTH)+LEN(MTH))

NEG:	RETURN, STRSUB(TXTSTR,LOC(N),9999)

	END
