;+
; NAME:
;    LAYOUT_SUBPLOTS
; PURPOSE:
;    Find optimum number of rows and columns for N subplots in a rectangle.
;    Given the aspect ratios of a main rectangle and of subplots and the number 
;    of subplots, find the number of rows and columns it takes to fit all
;    subplots into the main rectangle with the least reduction in subplot size.
;    Assumes aspect of plot including axes and titles equals aspect of plot
;    alone.
; CALLING SEQUENCE:
;    LAYOUT_SUBPLOTS, ASPECTMAIN_XONY, ASPECTSUB_XONY, N, NX, NY
; INPUTS:
;    ASPECTMAIN_XONY = FLOAT scalar. Aspect ratio (Xlen/Ylen) of main rectangle.
;    ASPECTSUB_XONY  = FLOAT scalar. Aspect ratio (Xlen/Ylen) of each subplot.
;    N               = Integer scalar. Number of subplots to be fitted into
;                      main rectangle.
; OUTPUTS:
;    NX              = Integer scalar. Number of columns required.
;    NY              = Integer scalar. Number of rows required.
; RESTRICTIONS:
;    Must give NY LT 100.
; PROCEDURE:
;    Try NY = 1 row and find max NX, then 2 rows, etc. till NX*NY GE N.
; MODIFICATION HISTORY:
;    Ian Grant, HIA/NRCC, 13 Jan 1992: Written in IDL2.
;    IFG, 23 Dec 1992: Added ON_ERROR.
;-

pro layout_subplots, aspectmain_xony, aspectsub_xony, n, nx, ny

on_error, 2
ny = 0
repeat begin
   ny = ny+1
   nx = fix( aspectmain_xony / (aspectsub_xony/ny) )
   endrep until ((n le nx*ny) or (ny ge 100))
if ny ge 100 then message, 'Too many plots on page'
return
end
