;+
; NAME:
;	OS_CHARS
; PURPOSE:
;	Return operating-system-specific characters used in file specifications.
; CALLING SEQUENCE:
;	OS_CHARS [,WILD1_CHAR=WILD1_CHAR] [,ENDDIR_CHAR=ENDDIR_CHAR]
; KEYWORD PARAMETERS:
;	WILD1_CHAR = scalar string of length 1, returns the character to stand 
;	   for a single character in a wildcard file specification.
;	ENDDIR_CHAR = scalar string of length 1, returns the character which 
;	   appears at the end of a directory specification.
; RESTRICTIONS:
;	For VMS or WINDOWS.
; MODIFICATION HISTORY:
;	Ian Grant, UWO,  3 Aug 1994: Written.
;	GRANT, 25 Jan 1995: Fixed keyword name from WILD1_CHAR to WILD_1CHAR.
;-

pro os_chars, wild_1char=wild_1char, enddir_char=enddir_char

on_error, 2

case !version.os of
   'vms': begin
      wild_1char = '%'
      enddir_char = ']'
      end
   'windows': begin
      wild_1char = '?'
      enddir_char = '\'
      end
   else: message, /inform, $
      'routine not implemented for '+!version.os+' operating system'
   endcase

return
end
