;+
; NAME:
;	ROUNDUP_125
; PURPOSE:
;	Round up to m*10^n, where m = 1, 2 or 5.
; CALLING SEQUENCE:
;	Result = ROUNDUP_125( X )
; INPUTS:
;	X = Numeric scalar. Value to be rounded up.
; OUTPUTS:
;	Result = X rounded up to m*10^n, where m = 1, 2 or 5.
; RESTRICTIONS:
;	Scalar argument only.
; MODIFICATION HISTORY:
;	GRANT, UWO, 23 Sep 1993: Written.
;-

function roundup_125, x

on_error, 2

power = 10.0 ^ floor(alog10(x))
mantissa = x/power

if mantissa le 1.0 then mantissa = 1.0 $
else if mantissa le 2.0 then mantissa = 2.0 $
else if mantissa le 5.0 then mantissa = 5.0 $
else mantissa = 10.0

return, mantissa * power
end
;+
; NAME:
;	ROUNDUP_NICE
; PURPOSE:
;	Round up to a "nice" round value, e.g. for the end of an axis.
;	Nice values have the form MANTISSA * 10^n, where MANTISSA is one of :
;	1, 11, 12, 13, 14, 15, 2, 3, 4, 5, 6, 7, 8, 9.
; CALLING SEQUENCE:
;	Result = ROUNDUP_NICE( XX )
; INPUTS:
;	XX = Integer or real scalar.
; OUTPUTS:
;	Result = Real scalar.
; RESTRICTIONS:
;	Argument must be a sscalar.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 1 May 1990, IDL1.
;	IFG, 29 April 1991: No changes needed for IDL2.
;	IFG, 23 Dec 1992: Added ON_ERROR.
;-

function roundup_nice, xx

on_error, 2
x = abs(xx)
if x eq 0 then begin
   mantissa = 0.0
   pow = 0.0
endif else begin
   pow = 10.0^fix(alog10(x))
   mantissa = x/pow
   if mantissa gt 1.5 then $
      mantissa = roundup(mantissa) $
   else $
      mantissa = 0.1*roundup(10.0*mantissa)
   endelse
return, sign(xx)*mantissa*pow
end
