;+
; NAME:
;	STREP
; PURPOSE:
;	Function to do string editing by position.
; CATEGORY:
;	String manipulation.
; CALLING SEQUENCE:
;	newstring = STREP(string,cmd,p,ss,[iflg])
; INPUTS:
;	string = string to edit.
;         cmd = edit command:
;               'P' = precede position p with substring ss.
;               'F' = follow position p with substring ss.
;               'R' = replace text starting at position p
;                     with text from substring ss.
;               'D' = delete N characters starting at
;                     position p.  The calling sequence for
;                     this command is slightly different:
;                     IFLG = STREP(string,'D',p,n,[iflg])
;                     Where n = number of characters to delete.
;          p = character position to use.
;              0 = first char.  Any number larger
;              than the string length = last char.
;          ss = substring to use.  For 'D' command
;              n is used instead of ss.
; OUTPUTS:
;	newstring = edited string. 
; OPTIONAL OUTPUT:
;	iflg = 0 for a successful edit,
;                  iflg = -1 for an error and no change to string.
; PROCEDURE:
;	Convert strings to byte arrays and process them.
; MODIFICATION HISTORY:
;	Written by R. Sterner, 27 Dec, 1984.
;	Johns Hopkins University Applied Physics Laboratory.
;     (FROM AN IDL1 USER LIBRARY)
;	Ian Grant, UWO, 21 Jan 1993: No changes needed for IDL2.
;-

	FUNCTION STREP,S,CMD,IP,SS,IFLG  ; string, command, which, substrng, err

	IF N_PARAMS(0) LT 4 THEN BEGIN $
	  PRINT,'Too few arguments in call to STREP'
	  RETURN,S
	ENDIF
	N = STRLEN(S) - 1
	IF N LT 0 THEN $
	  IF CMD EQ 'D' THEN RETURN, '' ELSE RETURN, SS
	P = IP>0<N
	BS = BYTE(S)
	IF (CMD NE 'D') THEN  BSS = BYTE(SS)
	JFLG = 0

	CASE CMD OF
  'P':	BEGIN
	IF P EQ 0 THEN T = [BSS,BS] ELSE $
		T = [BS(0:P-1),BSS,BS(P:*)]
	END
  'F':	BEGIN
	IF P EQ N THEN BEGIN
	  T = [BS,BSS]
	ENDIF ELSE BEGIN
	  IF IP GE 0 THEN BEGIN
	    T = [BS(0:P),BSS,BS(P+1:*)]
	  ENDIF ELSE BEGIN
	    T = [BSS, BS]
	  ENDELSE
	ENDELSE
	END
  'R':  BEGIN
	NSS = STRLEN(SS)
	IF NSS GT N - P + 1 THEN $
		T = [BS(0:P-1),BSS] $
	ELSE BEGIN $
		T = BS
		T(P) = BSS
	ENDELSE
	END
  'D':	BEGIN
	ND = SS < (N + 1)
	IF P EQ 0 THEN $
	  IF ND EQ N+1 THEN T = '' ELSE $
	    T = [BS(ND:*)]
	IF P GT 0 THEN $
	  IF ND+P-1 GE N THEN $
	    T = [BS(0:P-1)] ELSE $
	    T = [BS(0:P-1),BS(ND+P:*)]
	END
  ELSE: JFLG = -1
  ENDCASE

	IF JFLG NE 0 THEN T = S
	IF JFLG EQ 0 THEN T = STRING(T)
	IF N_PARAMS(0) EQ 5 THEN IFLG = JFLG

	RETURN,T
	END
