;+
; NAME:
;	Y_CH_SIZE
; PURPOSE:
;	Return the Y dimension of a character in DATA, DEVICE or NORMAL units.
; CALLING SEQUENCE:
;	Result = Y_CH_SIZE( [/DEVICE] [/DATA] [/NORMAL] )
; INPUTS:
;	None.
; KEYWORD PARAMETERS:
;	DATA, DEVICE, NORMAL: At most one of these keywords may be present and
;	   nonzero. The default is DEVICE. The Y size of a character in the
;	   selected coordinate system is returned.
; OUTPUTS:
;	Result = Float scalar. The character height in the selected coordinate
;	   system.
; PROCEDURE:
;	Converts the points (0, !D.Y_CH_SIZE) and (0,0) to the requested
;	coordinate system and returns the difference between the Y coordinates.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 27 Aug 1991, IDL2.
;	IFG, 4 Jan 1993: Added ON_ERROR.
;-

function y_ch_size, device=device, data=data, normal=normal

on_error, 2
case howmany([keyword_set(device), keyword_set(data), keyword_set(normal)]) of
   0: device = !true
   1: dummy = 0
   else: message, 'More than one coordinate system selected'
   endcase

case !true of
   keyword_set(device): return, !d.y_ch_size
   keyword_set(data):   return, $
      ((convert_coord( 0, !d.y_ch_size, /device, /to_data))(1) - $
       (convert_coord( 0, 0,            /device, /to_data))(1))
   keyword_set(normal): return, $
      ((convert_coord( 0, !d.y_ch_size, /device, /to_normal))(1) - $
       (convert_coord( 0, 0,            /device, /to_normal))(1))
   endcase
end
